<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>@default</name>
    <message>
        <source>Jabber/XMPP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Data transfers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>External address</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CertificateDisplayDialog</name>
    <message>
        <source>Certificate Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Certificate Validation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Valid From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Valid Until</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Serial Number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The certificate is valid.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The certificate is NOT valid!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reason: %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subject Details:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Issuer Details:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Organization:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Organizational unit:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Locality:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>State:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Country:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Common name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XMPP name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Email:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CertificateErrorDialog</name>
    <message>
        <source>The %1 certificate failed the authenticity test.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FacebookProtocolFactory</name>
    <message>
        <source>Facebook ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your username is available at &lt;a href=&apos;https://www.facebook.com/editaccount.php?settings&apos;&gt;https://www.facebook.com/editaccount.php?settings&lt;/a&gt; under Username field. If this field is empty, you can choose your Username and enter it there.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GTalkProtocolFactory</name>
    <message>
        <source>Gmail/Google Talk ID:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HttpConnect</name>
    <message>
        <source>Authentication failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid reply</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HttpProxyGetStream</name>
    <message>
        <source>Authentication failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid reply</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HttpProxyPost</name>
    <message>
        <source>Authentication failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid reply</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>JabberActions</name>
    <message>
        <source>Resend Subscription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Subscription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ask for Subscription</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>JabberAddAccountWidget</name>
    <message>
        <source>&lt;a href=&apos;#&apos;&gt;What is my username?&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Account Identity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>JabberChangePasswordWindow</name>
    <message>
        <source>Change Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Old Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Enter current password for your XMPP/Jabber account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Enter new password for your XMPP/Jabber account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retype new password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Changing password was successful.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An error has occurred. Please try again later.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid data entered in required fields.

Password entered in both fields (&quot;Password&quot; and &quot;Retype password&quot;) must be the same!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>JabberContactPersonalInfoWidget</name>
    <message>
        <source>Full Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Family Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Birthdate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>City</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E-Mail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Website</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>JabberCreateAccountWidget</name>
    <message>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retype Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Account Identity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More options:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manually Specify Server Host/Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encrypt connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Legacy SSL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Probe legacy SSL port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Register Account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot enable secure connection. SSL/TLS plugin not found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Legacy secure connection (SSL) is only available in combination with manual host/port.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid data entered in required fields.

Password entered in both fields (&quot;New password&quot; and &quot;Retype password&quot;) must be the same!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>JabberEditAccountWidget</name>
    <message>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change your password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Account Identity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;font size=&apos;-1&apos;&gt;&lt;i&gt;Select or enter the identity that will be associated with this account.&lt;/i&gt;&lt;/font&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Personal Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manually specify server host/port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encrypt connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Never</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Legacy SSL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Probe legacy SSL port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow plaintext authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Over encrypted connection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resource</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use hostname as a resource</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Priority</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Data transfer proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send composing events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send inactivity events (end/suspend conversation)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot enable secure connection. SSL/TLS plugin not found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Legacy SSL is only available in combination with manual host/port.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm account removal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to remove account %1 (%2)?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proxy configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Publish system information</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>JabberPersonalInfoWidget</name>
    <message>
        <source>Full name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Family name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Birth year</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>City</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E-Mail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Website</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>JabberProtocolFactory</name>
    <message>
        <source>User JID:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>JabberServerRegisterAccount</name>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This server does not support registration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There was an error registering the account.
Reason: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>JabberSubscriptionService</name>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The user %1 removed subscription to you. You will no longer be able to view his/her online/offline status. Do you want to delete the contact?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kadu - authorize user?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The user %1 (%2) is asking for subscription from you. He will be able to view your online/offline status. Do you want to authorize the contact?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>JabberWaitForAccountRegisterWindow</name>
    <message>
        <source>Plase wait. New XMPP account is being registered.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Registration was successful. Your new XMPP username is %1.
Store it in a safe place along with the password.
Now please add your friends to the buddy list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An error has occurred during registration. Please try again later.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MiniClient</name>
    <message>
        <source>Server Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The server does not support TLS encryption.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There was an error communicating with the Jabber server.
Details: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>&amp;Details...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Connect anyway</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Trust this certificate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Trust this domain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The server did not present a certificate.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Certificate is valid.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The hostname does not match the one the certificate was issued to.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General certificate validation error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No certificate presented.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hostname mismatch.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Certificate.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General validation error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>First Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>E-mail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>City</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>State</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zipcode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Phone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShowXmlConsoleActionDescription</name>
    <message>
        <source>Show XML Console</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TestDlg</name>
    <message>
        <source>XMPP Test</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 v1.0

Utility to demonstrate the Iris XMPP library.

Currently supports:
  draft-ietf-xmpp-core-21
  JEP-0025

Copyright (C) 2003 Justin Karneges</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please enter the Full JID to connect with.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must specify a host:port for the proxy.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must at least enter a URL to use http poll.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please enter the proxy host in the form &apos;host:port&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please enter the host in the form &apos;host:port&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error: SSF Min is greater than SSF Max.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error: TLS not available.  Disable any TLS options.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bad XML input (%1,%2): %3
Please correct and try again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bad Stanza &apos;%1&apos;.  Must be &apos;message&apos;, &apos;presence&apos;, or &apos;iq&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must enter at least one stanza!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter the password for %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XMPP::ClientStream</name>
    <message>
        <source>Offered mechanisms: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XMPP::Features::FeatureName</name>
    <message>
        <source>ERROR: Incorrect usage of Features class</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Register</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Groupchat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service Discovery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VCard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Execute command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add to roster</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XMPP::JT_VCard</name>
    <message>
        <source>No VCard available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XMPP::JabberClient</name>
    <message>
        <source>SSL support could not be initialized for account %1. This is most likely because the QCA TLS plugin is not installed on your system.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The server does not support TLS encryption.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There was an error communicating with the server.
Details: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XML Parsing Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XMPP Protocol Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generic stream error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Conflict(remote login replacing this one)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Timed out from inactivity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internal server error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid XML</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Policy violation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server out of resources</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server is shutting down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XMPP Stream Error: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to connect to server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error connecting to proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error during proxy negotiation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Proxy authentication failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Socket/stream error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection Error: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host no longer hosted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A required remote connection failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>See other host: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server does not support proper XMPP version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stream Negotiation Error: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server rejected STARTTLS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TLS handshake error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Broken security layer (TLS)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No appropriate mechanism available for given security settings(e.g. SASL library too weak, or plaintext authentication not enabled)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bad server response</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server failed mutual authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encryption required for chosen SASL mechanism</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid account information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid SASL mechanism</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid realm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SASL mechanism too weak for this account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not authorized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Temporary auth failure</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication error: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Broken security layer (SASL)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XMPP::Stanza::Error::Private</name>
    <message>
        <source>Bad request</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The sender has sent XML that is malformed or that cannot be processed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Conflict</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Access cannot be granted because an existing resource or session exists with the same name or address.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Feature not implemented</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The feature requested is not implemented by the recipient or server and therefore cannot be processed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Forbidden</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The requesting entity does not possess the required permissions to perform the action.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The recipient or server can no longer be contacted at this address.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internal server error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The server could not process the stanza because of a misconfiguration or an otherwise-undefined internal server error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The addressed JID or item requested cannot be found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>JID malformed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The sending entity has provided or communicated an XMPP address (e.g., a value of the &apos;to&apos; attribute) or aspect thereof (e.g., a resource identifier) that does not adhere to the syntax defined in Addressing Scheme.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not acceptable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The recipient or server understands the request but is refusing to process it because it does not meet criteria defined by the recipient or server (e.g., a local policy regarding acceptable words in messages).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not allowed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The recipient or server does not allow any entity to perform the action.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not authorized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The sender must provide proper credentials before being allowed to perform the action, or has provided improper credentials.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Payment required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The requesting entity is not authorized to access the requested service because payment is required.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Recipient unavailable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The intended recipient is temporarily unavailable.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redirect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The recipient or server is redirecting requests for this information to another entity, usually temporarily.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Registration required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The requesting entity is not authorized to access the requested service because registration is required.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remote server not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A remote server or service specified as part or all of the JID of the intended recipient does not exist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remote server timeout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A remote server or service specified as part or all of the JID of the intended recipient (or required to fulfill a request) could not be contacted within a reasonable amount of time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resource constraint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The server or recipient lacks the system resources necessary to service the request.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service unavailable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The server or recipient does not currently provide the requested service.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subscription required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The requesting entity is not authorized to access the requested service because a subscription is required.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Undefined condition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The error condition is not one of those defined by the other conditions in this list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unexpected request</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The recipient or server understood the request but was not expecting it at this time (e.g., the request was out of order).</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XMPP::Task</name>
    <message>
        <source>Disconnected</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XmlConsole</name>
    <message>
        <source>XML Console - %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
